.rer-contextual-portlets-right {
    width: 17em;
    margin-left: 1em;
    float: right;
}

body.portaltype-bando #content .rer-contextual-portlets a {
    background: none;
    padding:1px 0 1px 1px;
}

.rer-contextual-description {
    margin-bottom: 10px;
}

.contextualbody .navTreeItem li {
    list-style-type:none;
}

.rer-contextual-portlets ul {
    margin: 0.5em 0 0 0.5em;
}

.contextualbody .navTreeItem a, 
.contextualbody dd.portletItem .navTreeItem a {
    display:inline
}

.tableRight{
    width:100%;
}

.bandiColumnRight{
    width:40%;
    float:right;
    margin-left: 1em;
}

/*** etichette bandi ***/

.bandoInfos .bandoStateClass,
.bandoTitle .bandoStateClass {
    background-position: 5px 0;
	background-repeat: no-repeat;
	display: block;
	float: left;
	font-size: 0.8em;
	font-weight: normal;
	margin-right: 1em;
	padding-top: 13px;
	text-transform: uppercase;
	width: 57px;
	min-width:57px;
	text-align: center;
}

a.bandoTitle {
    border-bottom: 1px solid #CCCCCC;
    text-decoration: none;
}

.bandoInfos .bandoStateClass{
	margin-top:4px
}

.bandoTitle .bandoStateClass {
    font-size: 70%;
	margin-bottom: 0;
	margin-top: 7px;
	text-align: center;
}

.searchResults .bandoTitle .bandoStateClass {
	margin-top: 3px;
}

h3.bandoTitle{
	margin-top:3px
}

dt.bandoTitle .state-closed,
.bandoInfos .state-closed {
    background-image: url(++resource++rer.bandi.images/bando_closed.png);
    color: #700;
}
dt.bandoTitle .state-open,
.bandoInfos .state-open {
    background-image: url(++resource++rer.bandi.images/bando_open.png);
    color: #255a01;
}

dt.bandoTitle .state-inProgress,
.bandoInfos .state-inProgress {
    background-image: url(++resource++rer.bandi.images/bando_inprogress.png);
    color: #9c6f02;
}

dt.bandoTitle {
    font-size: 120%;
    font-weight: normal;
    margin-top: 2em;
}

.bandoDetail {
    clear: both;
}

dd.bandoDetail,
dl.searchResults dd.bandoDetail {
    margin: 0 0 0 70px;
    clear:none;
}

dl.bandoItem {
    border-bottom: 1px dashed #CCC;
    padding: 0.5em 0 0.7em;
    margin: 0.5em 0;
}

.labelTB {
    font-weight: bold;
}

.portletBandi .bandoDescription,
.portletBandi .bandoType,
.portletBandi .bandoDates{
	margin-left:70px;
}

.portletBandi h3.bandoTitle{
    margin-left:67px;
}

.siteSelection {
    margin-left: 2em;
    margin-top: 1em;
}
